# Example 10.3, Puerto Rican Employment and the Minimum Wage
# Data set: prminwge

# Function for result reporting
source("_report.R")

# Load the data and estimate the model in the background
load("prminwge.Rdata")
names(data)[names(data)=="lprepop"]="lprepop.t"
names(data)[names(data)=="lmincov"]="lmincov.t"
names(data)[names(data)=="lusgnp"]="lusgnp.t"
data=ts(data,start=1950,frequency=1)
model=lm(lprepop.t~lmincov.t+lusgnp.t,data=data)
dig=c(2,3,3,3)

# Describe the model
cat("Model to estimate: lprepop.t = beta0 + beta1 * lmincov.t + beta2 * lusgnp.t + u.t",
    "\nwhere lprepop is ", paste(desc[desc[,1]=="lprepop",2]), " (prepop: ", paste(desc[desc[,1]=="prepop",2]), ")",
    "\nlmincov is ", paste(desc[desc[,1]=="lmincov",2]), " (mincov: ", paste(desc[desc[,1]=="mincov",2]), ", with avgmin: ", paste(desc[desc[,1]=="avgmin",2]), ", avgwage: ", paste(desc[desc[,1]=="avgwage",2]), " and avgcov: ", paste(desc[desc[,1]=="avgcov",2]), ")",
    "\nand lusgnp is ", paste(desc[desc[,1]=="lusgnp",2]), " (usgnp: ", paste(desc[desc[,1]=="usgnp",2]), ")",
    sep="")

# Report results
{
  cat("The estimated regression line is")
  reportreg(model,dig,suffix=".hat",adj=T)
}

# Interpretation
cat("The coefficient on mincov, ", printcoef(model,2,dig[2]), ", is the predicted elasticity of prepop with respected to mincov, and indicates that an increase in avgmin lowers prepop, consistent with classical economic theories. The coefficient is statistically significant with a t statistic of ",
    printt(model,2,dig[2]), ". lusgnp is not significant in this model",
    sep="")