# Example 11.5, Expectations Augmented Phillips Curve
# Data set: phillips

# Function for result reporting
source("_report.R")

# Load the data and estimate the model in the background
load("phillips.Rdata")
names(data)[names(data)=="cinf"]="cinf.t"
names(data)[names(data)=="unem"]="unem.t"
data=ts(data[data$year<=1996,],start=1948,frequency=1)    # Refine the data
model=lm(cinf.t~unem.t,data=data)
dig=c(2,3,3)

# Describe the model
cat("A linear version of the expectations augmented Phillips curve can be written as",
    "\ninf.t - inf(e).t = beta1 (unem.t - mu0) + e.t",
    "\nwhere inf is inflation rate, inf(e) is the expected rate of inflation formed in year t - 1, unem is unemployment rate and mu0 is the natural rate of unemployment. The difference between the first two terms is unanticipated inflation, and that between the last two terms is cyclical unemployment. A tradeoff between unanticipated inflation and cyclical unemployment would suggest beta1 < 0",
    "\nIf we assume the expected rate of inflation is the same as the inflation rate in the previous year, the model can be rewritten as",
    "\ncinf.t = beta0 + beta1 * unem.t + e.t",
    "\nwhere cinf.t is inf.t - inf.t_1",
    "\nThe error term, e.t, represents a supply shock, and is typically assumed to be uncorrelated with unem.t. We assume TS1' through TS5' hold")

# Report results
{
  cat("The estimated regression line is")
  reportreg(model,dig,suffix=".hat",adj=T)
}

# Interpretation
cat("The coefficient on unem is statistically significant with a two-sided p-value of ",
    round(summary(model)$coef[2,"Pr(>|t|)"],3), ", and implies that an increase of 1 percentage point in unem is precicted to cause cinf to fall by ",
    printabscoef(model,2,dig[2]), " percentage point",
    "\nAlso, since beta0 = - beta1 * mu0, we can estimate mu0 to be about ",
    printcoef(model,1,dig[1]), "/", printabscoef(model,2,dig[2]), " = ",
    round(as.numeric(printcoef(model,1,dig[1]))/as.numeric(printabscoef(model,2,dig[2])),2),
    ", which is consistent with empirical records",
    sep="")