# Example 12.2, Testing for AR(1) Serial Correlation in the Minimum Wage Equation
# Data set: prminwge

# Function for result reporting
source("_report.R")

# Load the data and estimate the model in the background
load("prminwge.Rdata")
names(data)[names(data)=="lprepop"]="lprepop.t"
names(data)[names(data)=="lmincov"]="lmincov.t"
names(data)[names(data)=="lprgnp"]="lprgnp.t"
names(data)[names(data)=="lusgnp"]="lusgnp.t"
tsdata=ts(data,start=1950,frequency=1)
model=lm(lprepop.t~lmincov.t+lprgnp.t+lusgnp.t+t,data=tsdata)
dig=c(2,3,2,2,3,3)

# Recap the previous example and report new estimation results
{
  cat("This example closely follows Example 10.9. We estimated the model lprepop.t = beta0 + beta1 * lmincov.t + beta2 * lusgnp.t + beta3 * t + u.t in the previous example. Here we add another independent variable, lprgnp.t, which is ",
      paste(desc[desc[,1]=="lprgnp",2]), " (prgnp: ", paste(desc[desc[,1]=="prgnp",2]), "). The estimated regression line is",
      sep="")
  reportreg(model,dig,suffix=".hat",adj=T)
}

# Test for serial correlation
uhat.t=ts(model$residuals,start=1950,frequency=1)
data=cbind(data,as.data.frame(cbind(uhat.t,uhat.t_1=lag(uhat.t,k=-1)))[-39,])
tsdata=ts(data,start=1950,frequency=1)
m1=lm(uhat.t~lmincov.t+lprgnp.t+lusgnp.t+t+uhat.t_1,data=tsdata)
m2=lm(uhat.t~uhat.t_1,data=tsdata)
d1=c(2,3,3,3,4,3,3)
{
  cat("To test for AR(1) serial correlation without the strict exogeneity assumption, we regress the residuals from the above equation on its all four independent variables, as well as the first lag of the residuals",
      "\nThe model to estimate is hence: uhat.t = beta0 + beta1 * lmincov.t + beta2 * lusgnp.t + beta3 * t + rho * uhat.t_1 + e.t"
      "\nThe regression result is")
  reportreg(m1,d1,suffix=".hat",adj=T)
}

# Interpretation
cat("The coefficient on uhat.t_1 is ", printcoef(m1,6,d1[6]), ", with a t statistic of ", printt(m1,6,accrte=T),
    " and a two-sided p-value of ", round(summary(m1)$coef[6,"Pr(>|t|)"],3), ". Therefore, there is strong evidence of AR(1) serial correlation, making the usual OLS t statistics obtained in the previous example invalid",
    "\nIncidentally, if we use the test with strictly exogeneous regressors, i.e. regressing uhat.t on uhat.t_1 (with an intercept), we obtain rhohat = ",
    printcoef(m2,2,3), " and t = ", printt(m2,2,accrte=T), ", which gives similar conclusion as the previous test",
    sep="")