# Example 12.3, Testing for AR(3) Serial Correlation
# Data set: barium

# Function for result reporting
source("_report.R")

# Load the data and estimate the model in the background
load("barium.Rdata")
tsdata=ts(data,start=c(1978,2),frequency=12)
model=lm(lchnimp~lchempi+lgas+lrtwex+befile6+affile6+afdec6,data=tsdata)
dig=c(2,2,3,3,3,3,3,3)

# Recap the model
{
  cat("This example closely follows Example 10.5. The regression result in the previous example was")
  reportreg(model,dig,adj=T)
}

# Test for serial correlation
uhat.t=ts(model$residuals,start=c(1978,2),frequency=12)
temp=cbind(uhat.t,uhat.t_1=lag(uhat.t,k=-1),uhat.t_2=lag(uhat.t,k=-2),uhat.t_3=lag(uhat.t,k=-3))
data=cbind(data,as.data.frame(temp)[-(132:134),])
tsdata=ts(data,start=c(1978,2),frequency=12)
m1=lm(uhat.t~lchempi+lgas+lrtwex+befile6+affile6+afdec6+uhat.t_1+uhat.t_2+uhat.t_3,data=tsdata)
d1=c(2,2,3,3,3,3,3,3,3,3,3)
{
  cat("Since the regression uses monthly data, we want to test for AR(3) serial correlation. Hence we regress the residuals from the equation on its all six independent variables, as well as the first, second and third lags of the residuals",
      "\nThe model to estimate is hence: uhat.t = beta0 + beta1 * lchempi + beta2 * lgas + beta3 * lrtwex + beta4 * befile6 + beta5 * affile6 + beta6 * afdec6 + rho1 * uhat.t_1 + rho2 * uhat.t_2 + rho3 * uhat.t_3 + e.t",
      "\nThe regression result is")
  reportreg(m1,d1,suffix=".hat",adj=T)
}

# Interpretation
tsdata=ts(data[-(1:3),],start=c(1978,5),frequency=12)
m2=lm(uhat.t~lchempi+lgas+lrtwex+befile6+affile6+afdec6,data=tsdata)
Fstat=round((summary(m1)$r.squared-summary(m2)$r.squared)/(1-summary(m1)$r.squared)*((nrow(m1$model)-nrow(summary(m1)$coef))/3),2)
p=round(pf(Fstat,3,nrow(m1$model)-nrow(summary(m1)$coef),lower.tail=F),4)
cat("The F statistic for the joint significance of the three lagged residuals is ", Fstat,
    ". With numerator df = 10 and denominator df = ", nrow(m1$model)-nrow(summary(m1)$coef),
    ", the p-value is ", p, ", which is strong evidence of AR(3) serial correlation",
    sep="")