# Example 12.7, The Puerto Rican Minimum Wage
# Data set: prminwge

# Function for result reporting
source("_report.R")

# Load the data and estimate the model in the background
load("prminwge.Rdata")
names(data)[names(data)=="lprepop"]="lprepop.t"
names(data)[names(data)=="lmincov"]="lmincov.t"
names(data)[names(data)=="lprgnp"]="lprgnp.t"
names(data)[names(data)=="lusgnp"]="lusgnp.t"
tsdata=ts(data,start=1950,frequency=1)
model=lm(lprepop.t~lmincov.t+lprgnp.t+lusgnp.t+t,data=tsdata)
dig=c(2,4,2,2,3,3)

# Prepare PW estimation
rho=0
m=model
tilda=tsdata[,c("lprepop.t","lmincov.t","lprgnp.t","lusgnp.t","t")]
obs1=tilda[1,]
uhat.t=ts(m$residuals)
repeat{
  oldrho=rho
  res=as.data.frame(cbind(uhat.t,uhat.t_1=lag(uhat.t,k=-1)))
  mres=lm(uhat.t~0+uhat.t_1,data=res)
  rho=as.numeric(mres$coef[1])
  if(abs(oldrho-rho)<10^(-8)) break
  tilda=cbind(lprepop=tsdata[,"lprepop.t"]-rho*lag(tsdata[,"lprepop.t"],k=-1),
              lmincov=tsdata[,"lmincov.t"]-rho*lag(tsdata[,"lmincov.t"],k=-1),
              lprgnp=tsdata[,"lprgnp.t"]-rho*lag(tsdata[,"lprgnp.t"],k=-1),
              lusgnp=tsdata[,"lusgnp.t"]-rho*lag(tsdata[,"lusgnp.t"],k=-1),
              t=tsdata[,"t"]-rho*lag(tsdata[,"t"],k=-1)
              )
  tilda=ts(rbind(obs1*(1-rho^2)^0.5,tilda))
  cons=c((1-rho^2)^0.5,rep(1-rho,nrow(tsdata)-1))
  m=lm(lprepop.t~0+cons+lmincov.t+lprgnp.t+lusgnp.t+t,data=tilda)
  fit=m$coef[1]+m$coef[2]*tsdata[,"lmincov.t"]+m$coef[3]*tsdata[,"lprgnp.t"]+m$coef[4]*tsdata[,"lusgnp.t"]+m$coef[5]*tsdata[,"t"]
  uhat.t=ts(tsdata[,"lprepop.t"]-fit)
}

# Recap the model
{
  cat("This example closely follows Example 12.2. We estimated the model: lprepop.t = beta0 + beta1 * lmincov.t + beta2 * lprgnp.t + beta3 * lusgnp.t + beta4 * t + u.t in the previous example. The estimation result, with usual OLS standard errors reported, was")
  reportreg(model,dig,suffix=".hat",adj=T)
}

# Obtain SC-robust SE
uhat=model$residuals
rhat=lm(lmincov.t~lprgnp.t+lusgnp.t+t,data=tsdata)$residuals
ahat=ts(uhat*rhat)
vhat=sum(ahat^2)+(4/3)*sum(ahat*lag(ahat,k=-1))+(2/3)*sum(ahat*lag(ahat,k=-2))
se=(summary(model)$coef[2,"Std. Error"]/summary(model)$sigma)^2*sqrt(vhat)
cat("Since we found strong evidence of serial correlation in Example 10.2, we obtain an SC-robust standard error for the equation, in particular, for beta1hat. The estimate is ",
    printcoef(model,2,dig[2]), " with the usual OLS standard error of ", printse(model,2,dig[2]), ". The standard error of the regression is sigmahat = ",
    round(summary(model)$sigma,4), ". With g = 2, we can obtain vhat = ", round(vhat,6), ". Hence, the SC/heteroskedasticity-robust standard error is given by se(beta1hat) = [(",
    printse(model,2,dig[2]), "/", printse(model,2,dig[2]), ")^2] * sqrt(", round(vhat,6), ") = ",
    round(se,4), ". In this case, the robust standard error is only slightly greater than the usual one, and the robust t statistic is about ",
    round(as.numeric(model$coef[2])/se,2), ", so the estimated elasticity of prepop (employment rate) with respect to mincov (a proxy of minimum wage) is still very statistically significant",
    "\nFor comparison, the iterated PW estimation gives beta1hat = ", printcoef(m,2,4), ", with a standard error of ", printse(m,2,4),
    sep="")