# Example 5.2, Standard Errors in a Birth Weight Equation
# Data set: bwght

# Function for result reporting
source("_report.R")

# Load the data and estimate the model in the background
load("bwght.Rdata")
model1=lm(lbwght~cigs+lfaminc, data=data[1:(nrow(data)/2),])
model2=lm(lbwght~cigs+lfaminc, data=data)
dig1=c(3,4,4,3)
dig2=c(3,5,4,3)

# Describe the model
cat("\nModel to estimate: lbwght = beta0 + beta1 * cigs + beta2 * lfaminc + u",
    "\nwhere lbwght is ", paste(desc[desc[,1]=="lbwght",2]), " (bwght: ", paste(desc[desc[,1]=="bwght",2]), ")",
    "\ncigs is ", paste(desc[desc[,1]=="cigs",2]),
    "\nand lfaminc is ", paste(desc[desc[,1]=="lfaminc",2]), " (faminc: ", paste(desc[desc[,1]=="faminc",2]), ")",
    "\nWe estimate the model twice, based on the first half of the data and the whole data set, respectively",
    sep="")

# Report results
{
  cat("The estimation result based on the first half of the data is")
  reportreg(model1,dig1)
}
{
  cat("The estimation result based on the whole data set is")
  reportreg(model2,dig2)
}
# Interpretation
cat("The SE for beta1hat, using the first half of the data, is ", printse(model1,2,dig1[2]),
    ", while it is ", printse(model2,2,dig2[2]), " using the entire data set. The ratio of the two SEs is ",
    printse(model2,2,dig2[2]), "/", printse(model1,2,dig1[2]), " = ",
    round(as.numeric(printse(model2,2,dig2[2]))/as.numeric(printse(model1,2,dig1[2])),3),
    ". This is pretty close to the square root of the ratio of numbers of observations in the two model, √(",
    nrow(model1$model), "/", nrow(model2$model), ") = ",
    round(sqrt(nrow(model1$model)/nrow(model2$model)),3),
    ". The latter ratio implies that the SE using the larger sample size should be about 70.7% of that using the smaller sample",
    sep="")