# Example 5.3, Economic Model of Crime
# Data set: crime1

# Function for result reporting
source("_report.R")

# Load the data and estimate the models in the background
load("crime1.Rdata")
model=lm(narr86~pcnv+ptime86+qemp86, data=data)
dig=c(3,3,4,3,4)
data1=data.frame(data,model$residuals)
names(data1)[ncol(data1)]="utilda"
model1=lm(utilda~pcnv+avgsen+tottime+ptime86+qemp86, data=data1)
dig1=c(4,4,4,4,4,4,4)

# Describe the model and state the hypothesis
cat("We want to conduct the LM test on the hypothesis that in the following model, the variables avgsen and tottime have no effect on narr86 once the other factors have been controlled for, i.e. H0: beta2 = 0, beta3 = 0",
    "\nThe model is: narr86 = beta0 + beta1 * pcnv + beta2 * avgsen + beta3 * tottime + beta4 * ptime86 + beta5 * qemp86 + u",
    "\nwhere narr86 is ", paste(desc[desc[,1]=="narr86",2]),
    "\npcnv is ", paste(desc[desc[,1]=="pcnv",2]),
    "\navgsen is ", paste(desc[desc[,1]=="avgsen",2]),
    "\ntottime is ", paste(desc[desc[,1]=="tottime",2]),
    "\nptime86 is ", paste(desc[desc[,1]=="ptime86",2]),
    "\nand qemp86 is ", paste(desc[desc[,1]=="qemp86",2]),
    sep="")

# Report results
{
  cat("We first estimate the restricted model:")
  reportreg(model,dig,suffix="tilda")
}
{
  cat("Then we obtain the residuals, utilda, from the regression, and regress them on all the five independent variables",
      "\nThe regression result is:")
  reportreg(model1,dig1)
}

# Interpretation
cat("The second regression gives an R^2 of ", printr(model1,dig1[7]),
    ". Thus, the LM statistic is n * R^2 = ", nrow(model1$model), " * ", printr(model1,dig1[7]),
    " = ", round(nrow(model1$model)*as.numeric(printr(model1,dig1[7])),2),
    ". With df = 2, the 10% critical value in the chi-square distribution is 4.61 > ",
    round(nrow(model1$model)*as.numeric(printr(model1,dig1[7])),2),
    ", so we fail to reject H0 at the 10% level. The p-value is ",
    round(pchisq(round(nrow(model1$model)*as.numeric(printr(model1,dig1[7])),2),2,lower.tail=F),3),
    ", so we reject H0 at the 15% level",
    sep="")