# Example 6.3, Effects of Attendance on Final Exam Performance
# Data set: attend

# Function for result reporting
source("_report.R")

# Load the data, create new variables and estimate the model
load("attend.Rdata")
data$priGPAsq=(data$priGPA)^2
data$ACTsq=(data$ACT)^2
data$priGPA.atndrte=(data$priGPA)*(data$atndrte)
model=lm(stndfnl~atndrte+priGPA+ACT+priGPAsq+ACTsq+priGPA.atndrte,data=data)
dig=c(2,4,2,3,3,4,4,3)

# Describe the model
cat("Model to estimate: stndfnl = beta0 + beta1 * atndrte + beta2 * priGPA + beta3 * ACT + beta4 * priGPAsq + beta5 * ACTsq + beta6 * priGPA.atndrte + u",
    "\nwhere stndfnl is ", paste(desc[desc[,1]=="stndfnl",2]),
    "\natndrte is ", paste(desc[desc[,1]=="atndrte",2]),
    "\npriGPA is ", paste(desc[desc[,1]=="priGPA",2]),
    "\nACT is ", paste(desc[desc[,1]=="ACT",2]),
    "\nBesides, priGPAsq and ACTsq are quadratic terms in priGPA and ACT, respectively, and priGPA.atndrte is an interaction term between priGPA and atndrte",
    sep="")

# Report results
{
  cat("The estimated regression line is")
  reportreg(model,dig,adj=T)
}

# Interpretation
cat("The coefficient on atndrte alone implies that atndrte has a negative effect on stndfnl, which is incorrect. The actual effect of atndrte turns out to be ",
    printcoef(model,2,dig[2]), " + ", printcoef(model,7,dig[7]),
    " priGPA. When we plug in the mean priGPA, ", round(mean(data$priGPA),2),
    ", the effect is ", printcoef(model,2,dig[2]), " + ", printcoef(model,7,dig[7]),
    " * ", round(mean(data$priGPA),2), " = ",
    round(as.numeric(printcoef(model,2,dig[2]))+as.numeric(printcoef(model,7,dig[7]))*round(mean(data$priGPA),2),4),
    ", i.e. a 10 percentage point increase in atndrte increases stndfnl by ",
    10*round(as.numeric(printcoef(model,2,dig[2]))+as.numeric(printcoef(model,7,dig[7]))*round(mean(data$priGPA),2),4),
    " standard deviations from the mean final exam score",
    "\nBesides, while neither priGPA nor priGPA.atndrte is statistically significant alone, they are actually joint significant",
    sep="")