# Example 6.7, Predicting CEO Salaries
# Data set: ceosal2

# Function for result reporting
source("_report.R")

# Load the data and estimate the model in the background
load("ceosal2.Rdata")
model=lm(lsalary~lsales+lmktval+ceoten,data=data)
dig=c(3,3,3,4,3)

# Estimate alpha0 using both methods
alpha0hat=round(sum(exp(model$residuals))/nrow(model$model),3)
data$mhat=exp(model$coef[1]+model$coef[2]*data$lsales+model$coef[3]*data$lmktval+model$coef[4]*data$ceoten)
alpha0wedge=round(sum(data$salary*data$mhat)/sum(data$mhat^2),3)

# Describe the model
cat("Model to estimate: lsalary = beta0 + beta1 * lsales + beta2 * lmktval + beta3 * ceoten + u",
    "\nwhere lsalary is ", paste(desc[desc[,1]=="lsalary",2]), " (salary: ", paste(desc[desc[,1]=="salary",2]), ")",
    "\nlsales is ", paste(desc[desc[,1]=="lsales",2]), " (sales: ", paste(desc[desc[,1]=="sales",2]), ")",
    "\nlmktval is ", paste(desc[desc[,1]=="lmktval",2]), " (mktval: ", paste(desc[desc[,1]=="mktval",2]), ")",
    "\nand ceoten is ", paste(desc[desc[,1]=="ceoten",2]),
    sep="")

# Report results
{
  cat("The estimated regression line is")
  reportreg(model,dig)
}

# Interpretation
vars=c(1,log(5000),log(10000),10)
coefs=as.numeric(printcoef(model,1:4,dig[1:4]))
lsalaryhat=round(sum(vars*coefs),3)
exp=round(exp(lsalaryhat),3)
cat("The Duan smearing estimate is about alpha0hat = ", alpha0hat,
    ", and the regression estimate is about alpha0wedge = ", alpha0wedge,
    ". We can use either to predict salary at given values of sales, mktval and ceoten. When sales = 5000, mktval = 10000 and ceoten = 10, the predicted lsalary is ",
    lsalaryhat, ", and exp(lsalaryhat) is about ", exp, ". Using alpha0hat, the predicted salary is about ",
    round(alpha0hat*exp,3), "; using alpha0wedge, the prediction is about ", round(alpha0wedge*exp,3),
    ". As a comparison, the naive predition for salary is simply exp(lsalaryhat), with a value of ",
    exp, sep="")