# Example 6.8, Predicting CEO Salaries
# Data set: ceosal2

# Function for result reporting
source("_report.R")

# Load the data and estimate the model in the background
load("ceosal2.Rdata")
model=lm(lsalary~lsales+lmktval+ceoten,data=data)
dig=c(3,3,3,4,3)

# Estimate alpha0 using both methods
alpha0hat=round(sum(exp(model$residuals))/nrow(model$model),3)
data$mhat=exp(model$coef[1]+model$coef[2]*data$lsales+model$coef[3]*data$lmktval+model$coef[4]*data$ceoten)
alpha0wedge=round(sum(data$salary*data$mhat)/sum(data$mhat^2),3)

# Recap the model
{
  cat("This example closely follows Example 6.5. The estimation result in the previous example was")
  reportreg(model,dig)
}

# Interpretation
cat("After obtaining mhat, we can compute its correlation with salary, ",
    round(cor(data$mhat,data$salary),3), ", and its square, ",
    round(round(cor(data$mhat,data$salary),3)^2,3), ". Like an R^2, the latter is a measure of how well the log model explains the variation in salary (not lsalary)",
    "\nAs a comparison, we estimate a level-level model: salary = beta0 + beta1 * sales + beta2 * mktval + beta3 * ceoten + u, and it gives an R^2 of ",
    printr(model=lm(salary~sales+mktval+ceoten,data=data),3), ". Therefore, the log model explains more of the variation in salary, and is preferred in terms of goodness-of-fit",
    sep="")

# Prediction interval
data$lsales0=data$lsales-log(5000)
data$lmktval0=data$lmktval-log(10000)
data$ceoten0=data$ceoten-10
model0=lm(lsalary~lsales0+lmktval0+ceoten0,data=data)
see0hat=round(sqrt(as.numeric(printse(model0,1,dig[1]))^2+round((summary(model0)$sigma),3)^2),3)
cat("Furthermore, when we obtain a prediction interval for log(y0), since the the exponential function is strictly increasing, the lower/upper bounds of the interval can also be used to obtain a prediction interval for y0 at the same level. In this example, with the given values of the independent variables in Example 6.7 (sales = 5000, mktval = 10000, ceoten = 10), we create the following variables:",
    "\nlsales0 = lsales - log(5000)\nlmktval0 = lmktval - log(10000)\nceoten0 = ceoten - 10",
    "\nand estimate the model lsalary0 = beta0 + beta1 * lsales0 + beta2 * lmktval0 + beta3 * ceoten0 + u. In the estimation results, se(y0hat) = ",
    printse(model0,1,dig[1]), " and sigmahat = ", round((summary(model0)$sigma),3),
    ", which make se(e0hat) about ", see0hat,
    ". Thus, a 5% prediction interval for salary0 is (exp(", printcoef(model0,1,dig[1]),
    " - 1.96 * ", see0hat, "),exp(", printcoef(model0,1,dig[1]), " - 1.96 * ", see0hat,
    ")), or (", round(exp(as.numeric(printcoef(model0,1,dig[1]))-1.96*see0hat),3), ",",
    round(exp(as.numeric(printcoef(model0,1,dig[1]))+1.96*see0hat),3), "), a wide interval considering salary is in $1000s",
    sep="")