# Example 8.2, Heteroskedasticity-Robust F Statistic
# Data set: gpa3

# Function for result reporting
source("_report.R")

# Load the data and estimate the model in the background
load("gpa3.Rdata")
data=data[data$term==2,]      # Refine data to spring semester
model=lm(cumgpa~sat+hsperc+tothrs+female+black+white,data=data)
model0=lm(cumgpa~sat+hsperc+tothrs+female,data=data)    # Restricted model for joint test
dig=c(2,5,5,5,3,3,3,4)

# Describe the model
cat("Model to estimate: cumgpa = beta0 + beta1 * sat + beta2 * hsperc + beta3 * tothrs + beta4 * female + beta5 * black + beta6 * white + u",
    "\nwhere cumgpa is ", paste(desc[desc[,1]=="cumgpa",2]),
    "\nsat is ", paste(desc[desc[,1]=="sat",2]),
    "\nhsperc is ", paste(desc[desc[,1]=="hsperc",2]),
    "\ntothrs is ", paste(desc[desc[,1]=="tothrs",2]),
    "\nfemale is ", paste(desc[desc[,1]=="female",2]),
    "\nblack is ", paste(desc[desc[,1]=="black",2]),
    "\nwhite is ", paste(desc[desc[,1]=="white",2]),
    sep="")

# Report results
{
  cat("The estimated regression line is")
  reportreg(model,dig,adj=T,HC=T)
}

# Interpretation
cat("The differences between both sets of standard errors are not very big, and use of the robust t statistics does not change the statistical significance of any independent variable",
    "\nNow we want to conduct a joint significance test. The null hypothesis is that, after the other factors are controlled for, there are no differences in cumgpa by race, i.e. beta5 = 0, beta6 = 0. With the R^2 of the restricted model being ",
    printr(model0,dig[8]), ", the usual F statistic is given by [(", printr(model,dig[8]),
    " - ", printr(model0,dig[8]), ")/(1 - ", printr(model,dig[8]), ")](",
    nrow(model$model)-nrow(summary(model)$coef), "/2) = ", round((as.numeric(printr(model,dig[8]))-as.numeric(printr(model0,dig[8])))/(1-as.numeric(printr(model,dig[8])))*(nrow(model$model)-nrow(summary(model)$coef))/2,2),
    ". However, if heteroskedasticity is present, this version of the test is invalid. The heteroskedasticity-robust F statistic, or the Wald statistic, turns out to be ",
    round(waldtest(model,model0,vcov=vcovHC(model,type="HC0"))[2,"F"],2), ", and the p-value ",
    round(waldtest(model,model0,vcov=vcovHC(model,type="HC0"))[2,"Pr(>F)"],3), ". Using either the regular or the robust test, we reject the null hypothesis",
    sep="")
