# Example 8.3, Heteroskedasticity-Robust LM Statistic
# Data set: crime1

# Function for result reporting
source("_report.R")

# Load the data, create new variable and estimate the model
load("crime1.Rdata")
data$avgsensq=data$avgsen^2
model=lm(narr86~pcnv+avgsen+avgsensq+ptime86+qemp86+inc86+black+hispan,data=data)
dig=c(3,3,4,5,4,4,5,3,3,4)

# Describe the model
cat("Model to estimate: narr86 = beta0 + beta1 * pcnv + beta2 * avgsen + beta3 * avgsensq + beta4 * ptime86 + beta5 * qemp86 + beta6 * inc86 + beta7 * black + bata8 * hispan + u",
    "\nwhere narr86 is ", paste(desc[desc[,1]=="narr86",2]),
    "\npcnv is ", paste(desc[desc[,1]=="pcnv",2]),
    "\navgsen is ", paste(desc[desc[,1]=="avgsen",2]),
    "\navgsensq is the quadratic term in avgsen",
    "\nptime86 is ", paste(desc[desc[,1]=="ptime86",2]),
    "\nqemp86 is ", paste(desc[desc[,1]=="qemp86",2]),
    "\ninc86 is ", paste(desc[desc[,1]=="inc86",2]),
    "\nblack is ", paste(desc[desc[,1]=="black",2]),
    "\nand hispan is ", paste(desc[desc[,1]=="hispan",2]),
    sep="")

# Report results
{
  cat("The estimated regression line is")
  reportreg(model,dig,HC=T)
}

# Conduct LM test
m1=lm(narr86~pcnv+ptime86+qemp86+inc86+black+hispan,data=data)
m2=lm(m1$residuals~pcnv+avgsen+avgsensq+ptime86+qemp86+inc86+black+hispan,data=data)
LM=round(nrow(m1$model)*round(summary(m2)$r.squared,4),2)
p.LM=round(pchisq(LM,2,lower.tail=F),3)
m3=lm(avgsen~pcnv+ptime86+qemp86+inc86+black+hispan,data=data)
m4=lm(avgsensq~pcnv+ptime86+qemp86+inc86+black+hispan,data=data)
m13residuals=m1$residuals*m3$residuals
m14residuals=m1$residuals*m4$residuals
m5=lm(rep(1,nrow(m1$model))~0+m13residuals+m14residuals)
LMHC=round(nrow(m1$model)-sum(m5$residuals^2),2)
p.LMHC=round(pchisq(LMHC,2,lower.tail=F),3)

# Interpretation
turn=round(as.numeric(printcoef(model,3,dig[3]))/2/as.numeric(printabscoef(model,4,dig[4])),2)
cat("In this example, there are relatively substantial differences between some of the usual standard errors and the robust standard errors. For example, the usual t statistic on avgsensq is about ",
    printt(model,4,dig[4]), ", while the robust t statistic is about ", printt(model,4,dig[4],T),
    ", so avgsensq is more significant using the robust standard error",
    "\nThe turning point of the sign of the effect of avgsen on narr86 is given by ", printcoef(model,3,dig[3]),
    "/[2(", printabscoef(model,4,dig[4]), ")] = ", turn,
    ". That is, when avgsen is below ", turn, " months, it has a positive effect on narr86 and when it is below ",
    turn, " months, a negative effect",
    "\nTo test the statistical significance of the effect of avgsen on narr86, we conduct a LM test. The usual test gives an LM statistic of ",
    LM, "; in a chi-square distribution with df = 2, this yields a p-value of ", p.LM,
    ", so we fail to reject H0 at the 15% level. The heteroskedasticity-robust LM statistic is ",
    LMHC, ", and the corresponding p-value is ", p.LMHC, ", which is still not very strong evidence against H0. Thus, avgsen does not appear to have a strong effect on narr86, whether we use the usual or the robust LM test",
    sep="")
