# Example 8.5, Special Form of the White Test in the Log Housing Price Equation
# Data set: hprice1

# Function for result reporting
source("_report.R")

# Load the data and estimate the model in the background
load("hprice1.Rdata")
model=lm(lprice~llotsize+lsqrft+bdrms,data=data)
dig=c(2,3,3,3,3)

# Recap the model
{
  cat("This example closely follows Example 8.4. In the second part of the previous example, we estimated the model: lprice = beta0 + beta1 * llotsize + beta2 * lsqrft + beta3 * bdrms + u. The estimation result was")
  reportreg(model,dig)
}

# Test for HC
data$rhatsq=model$residuals^2
data$fitted=model$fitted.values
data$fittedsq=model$fitted.values^2
model0=lm(rhatsq~fitted+fittedsq,data=data)
LM=round(nrow(model0$model)*as.numeric(printr(model0,4)),2)
cat("Now we use the special form of the White test and the LM statistic to test for heteroskedasticity in the model. We regress squared uhat on the fitted values, yhat, and their square. This gives an R^2 of ",
    printr(model0,4), ". Thus the LM statistic is ", nrow(model0$model), "(", printr(model0,4), ") = ",
    LM, ", and the p-value is ", round(pchisq(LM,2,lower.tail=F),3), ". Still, we fail to reject the null hypothesis of homoskedastisity in the log model",
    sep="")